@@ -27,12 +27,12 @@ from .tools.drawing import blit
 from ..Clip import Clip
 from ..conf import FFMPEG_BINARY, IMAGEMAGICK_BINARY
 from ..tools import (subprocess_call, verbose_print,
-                           deprecated_version_of) 
+                      deprecated_version_of) 
 from ..decorators import  (apply_to_mask,
                            requires_duration,
                            outplace,
                            add_mask_if_none,
-                           time_can_be_tuple)
+                           convert_to_seconds)
 
 
 try:
@@ -117,12 +117,15 @@ class VideoClip(Clip):
     # EXPORT OPERATIONS
 
 
-    @time_can_be_tuple
+    @convert_to_seconds(['t'])
     def save_frame(self, filename, t=0, savemask=False):
         """ Save a clip's frame to an image file.
 
         Saves the frame of clip corresponding to time ``t`` in
-        'filename'. If ``savemask`` is ``True`` the mask is saved in
+        'filename'. ``t`` can be expressed in seconds (15.35), in
+        (min, sec), in (hour, min, sec), or as a string: '01:03:05.35'.
+        
+        If ``savemask`` is ``True`` the mask is saved in
         the alpha layer of the picture.
 
         """
@@ -133,9 +136,10 @@ class VideoClip(Clip):
         ffmpeg_write_image(filename, im)
 
 
-
+    @requires_duration
     def write_videofile(self, filename, fps=24, codec='libx264',
                  bitrate=None, audio=True, audio_fps=44100,
+                 preset="medium",
                  audio_nbytes = 4, audio_codec= 'libmp3lame',
                  audio_bitrate = None, audio_bufsize = 2000,
                  temp_audiofile=None,
@@ -278,63 +282,40 @@ class VideoClip(Clip):
             videofile = filename
 
         # enough cpu for multiprocessing ?
-        enough_cpu = (multiprocessing.cpu_count() > 2)
+        enough_cpu = (multiprocessing.cpu_count() > 1)
 
         verbose_print(verbose, "\nMoviePy: building video file %s\n"%filename
                                 +40*"-"+"\n")
 
-        if para and make_audio and  enough_cpu:
+        
+        if make_audio:
+            self.audio.write_audiofile(temp_audiofile,audio_fps,
+                                    audio_nbytes, audio_bufsize,
+                                    audio_codec, bitrate=audio_bitrate,
+                                    write_logfile=write_logfile,
+                                    verbose=verbose)
 
-            # Parallelize
-            verbose_print(verbose, "Writing audio/video in parrallel.\n")
-            audioproc = multiprocessing.Process(
-                    target=self.audio.write_audiofile,
-                    args=(temp_audiofile,audio_fps,audio_nbytes,
-                          audio_bufsize,audio_codec,
-                          audio_bitrate,
-                          verbose))
-
-            audioproc.start()
-            
-            ffmpeg_write_video(self, 
-                               videofile, fps, codec,
-                               bitrate=bitrate,
-                               write_logfile=write_logfile,
-                               verbose=verbose)
-            audioproc.join()
-            if audioproc.exitcode:
-                print ("WARNING: something went wrong with the audio"+
-                       " writing, Exit code %d"%audioproc.exitcode)
-        else:
-
-            # Don't parallelize
-            if make_audio:
-                self.audio.write_audiofile(temp_audiofile,audio_fps,
-                                        audio_nbytes, audio_bufsize,
-                                        audio_codec, bitrate=audio_bitrate,
-                                        write_logfile=write_logfile,
-                                        verbose=verbose)
-
-            ffmpeg_write_video(self,
-                               videofile, fps, codec,
-                               bitrate=bitrate,
-                               write_logfile=write_logfile,
-                               verbose=verbose)
+        ffmpeg_write_video(self, videofile, fps, codec,
+                           bitrate=bitrate,
+                           preset=preset,
+                           write_logfile=write_logfile,
+                           verbose=verbose)
 
         # Merge with audio if any and trash temporary files.
-        if merge_audio:
 
+        if merge_audio:
             verbose_print(verbose, "\n\nNow merging video and audio:\n")
             ffmpeg_merge_video_audio(videofile,temp_audiofile,
                                   filename, ffmpeg_output=True)
 
             if remove_temp:
                 os.remove(videofile)
-                if not isinstance(audio,str):
+                if make_audio:
                     os.remove(temp_audiofile)
-            verbose_print(verbose, "\nYour video is ready !\n")
 
+        verbose_print(verbose, "\nYour video is ready !\n")
 
+    @requires_duration
     def write_images_sequence(self, nameformat, fps=None, verbose=True):
         """ Writes the videoclip to a sequence of image files.
 
@@ -388,7 +369,8 @@ class VideoClip(Clip):
         verbose_print(verbose, "MoviePy: Done writing frames %s."%(nameformat))
 
         return filenames
-
+    
+    @requires_duration
     def write_gif(self, filename, fps=None, program= 'ImageMagick',
                opt="OptimizeTransparency", fuzz=1, verbose=True,
                loop=0, dispose=False):
@@ -499,7 +481,7 @@ class VideoClip(Clip):
             os.remove(f)
 
 
-
+    @requires_duration
     def write_gif2(self, filename, fps=None, program= 'ImageMagick',
                    opt="OptimizeTransparency", fuzz=1, verbose=True,
                    loop=0, dispose=False):
@@ -571,7 +553,7 @@ class VideoClip(Clip):
         cmd1a = cmd1+['-r', "%.02f"%fps, filename]
         cmd1b = cmd1+['-f', 'image2pipe','-vcodec', 'bmp', '-']
         
-        cmd2 = [IMAGEMAGICK_BINARY, '-delay', "%d"%int(100.0/fps),
+        cmd2 = [IMAGEMAGICK_BINARY, '-delay', "%.02f"%(100.0/fps),
                 "-dispose" ,"%d"%(2 if dispose else 1),
                 '-loop', '%d'%loop,
                 '-', '-coalesce']
@@ -593,11 +575,10 @@ class VideoClip(Clip):
         verbose_print(verbose, "\nMoviePy: building GIF file %s\n"%filename
                                 +40*"-"+"\n")
         verbose_print(verbose, "Generating GIF frames...\n")
-        nframes = int(self.duration*fps)+1
         
         try:
 
-            for frame in tqdm(self.iter_frames(fps=fps), total=nframes):
+            for frame in self.iter_frames(fps=fps, progress_bar=True):
                 proc1.stdin.write(frame.tostring())
             verbose_print(verbose, "Done.\n")
 
@@ -741,7 +722,7 @@ class VideoClip(Clip):
             mask = ColorClip(self.size, 1.0, ismask=True)
             return self.set_mask( mask.set_duration(self.duration))
         else:
-            get_frame = lambda t: np.ones(self.get_frame(t).shape)
+            get_frame = lambda t: np.ones(self.get_frame(t).shape, dtype=float)
             mask = VideoClip(ismask=True, get_frame = get_frame)
             return self.set_mask(mask.set_duration(self.duration))
 
@@ -883,13 +864,17 @@ class VideoClip(Clip):
     # CONVERSIONS TO OTHER TYPES
 
 
-    @time_can_be_tuple
-    def to_ImageClip(self,t=0):
+    @convert_to_seconds(['t'])
+    def to_ImageClip(self,t=0, with_mask=True):
         """
-        Returns an ImageClip made out of the clip's frame at time ``t``
+        Returns an ImageClip made out of the clip's frame at time ``t``,
+        which can be expressed in seconds (15.35), in (min, sec),
+        in (hour, min, sec), or as a string: '01:03:05.35'.
         """
-        return ImageClip(self.get_frame(t))
-
+        newclip = ImageClip(self.get_frame(t), ismask=self.ismask)
+        if with_mask and self.mask is not None:
+          newclip.mask = self.mask.to_ImageClip(t)
+        return newclip
 
 
     def to_mask(self, canal=0):
@@ -1056,7 +1041,7 @@ class ImageClip(VideoClip):
                 a = getattr(self, attr)
                 if a != None:
                     new_a =  a.fl_image(image_func)
-                    setattr(newclip, attr, new_a)
+                    setattr(self, attr, new_a)
 
 
 
@@ -1131,9 +1116,12 @@ class TextClip(ImageClip):
     -----------
 
     txt
-      either a string, or a filename. If txt is in a file and
-      whose name is ``mytext.txt`` for instance, then txt must be
-      equal to ``@mytext.txt`` .
+      A string of the text to write. Can be replaced by argument
+      ``filename``.
+
+    filename
+      The name of a file in which there is the text to write.
+      Can be provided instead of argument ``txt``
 
     size
       Size of the picture in pixels. Can be auto-set if
@@ -1184,15 +1172,16 @@ class TextClip(ImageClip):
 
 
 
-    def __init__(self, txt, size=None, color='black',
+    def __init__(self, txt=None, filename=None, size=None, color='black',
              bg_color='transparent', fontsize=None, font='Courier',
              stroke_color=None, stroke_width=1, method='label',
              kerning=None, align='center', interline=None,
              tempfilename=None, temptxt=None,
              transparent=True, remove_temp=True,
              print_cmd=False):
+        
 
-        if not txt.startswith('@'):
+        if txt is not None:
             if temptxt is None:
                 temptxt_fd, temptxt = tempfile.mkstemp(suffix='.txt')
                 try: # only in Python3 will this work
@@ -1202,7 +1191,8 @@ class TextClip(ImageClip):
                 os.close(temptxt_fd)
             txt = '@'+temptxt
         else:
-            txt = "'%s'"%txt
+            # use a file instead of a text.
+            txt = "@%"+filename
 
         if size != None:
             size = ('' if size[0] is None else str(size[0]),
